.. Copyright 2016, 2018 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.bootstrap.grid
-------------------------------

.. sidebar:: Examples in this section

   - tutorial.bootstrapgrids

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. automodule:: reahl.web.bootstrap.grid


Container
"""""""""

.. autoclass:: Container
   :members:

ColumnLayout
""""""""""""

.. autoclass:: ColumnLayout
   :members:

ColumnOptions
"""""""""""""

.. autoclass:: ColumnOptions
   :members:
   
ResponsiveSize
""""""""""""""

.. autoclass:: ResponsiveSize
   :members:


ContentJustification
""""""""""""""""""""

.. autoclass:: ContentJustification
   :members:

Alignment
"""""""""

.. autoclass:: Alignment
   :members:
